summaryrefslogtreecommitdiff
path: root/ttd.h
diff options
context:
space:
mode:
Diffstat (limited to 'ttd.h')
-rw-r--r--ttd.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/ttd.h b/ttd.h
index fa799e2df..aafb87b46 100644
--- a/ttd.h
+++ b/ttd.h
@@ -469,9 +469,10 @@ enum Sprites {
};
enum MAP_OWNERS {
- OWNER_TOWN = 0xf, // a town owns the tile
- OWNER_NONE = 0x10,// nobody owns the tile
- OWNER_WATER= 0x11,// "water" owns the tile
+ OWNER_TOWN = 0xf, // a town owns the tile
+ OWNER_NONE = 0x10,// nobody owns the tile
+ OWNER_WATER = 0x11,// "water" owns the tile
+ OWNER_SPECTATOR = 0xff, // spectator in MP or in scenario editor
};
VARDEF bool _savegame_sort_dirty;